#!/bin/bash

_dropshell_completions() {
    local cur prev opts
    COMPREPLY=()
    cur="${COMP_WORDS[COMP_CWORD]}"
    prev="${COMP_WORDS[COMP_CWORD-1]}"
    
    # List of main commands
    opts="help version status servers templates autocomplete_list_servers autocomplete_list_services"

    # If we're completing the first argument, show all commands
    if [[ ${COMP_CWORD} -eq 1 ]] ; then
        COMPREPLY=( $(compgen -W "${opts}" -- ${cur}) )
        return 0
    fi

    # Command-specific completions
    case "${prev}" in
        status)
            # No additional completions for status
            COMPREPLY=()
            ;;
        servers)
            # Use the new autocomplete_list_servers command
            local servers=($(dropshell autocomplete_list_servers))
            COMPREPLY=( $(compgen -W "${servers[*]}" -- ${cur}) )
            return 0
            ;;
        templates)
            # No additional completions for templates
            COMPREPLY=()
            ;;
        autocomplete_list_services)
            # Use the new autocomplete_list_servers command for server names
            local servers=($(dropshell autocomplete_list_servers))
            COMPREPLY=( $(compgen -W "${servers[*]}" -- ${cur}) )
            return 0
            ;;
        *)
            ;;
    esac
}

# Register the completion function
complete -F _dropshell_completions dropshell 